Coverage for C:\src\imod-python\imod\prepare\surface_water.py: 60%

1# Import for backwards compatibility

2 import warnings

3

4 from imod.prepare.topsystem import c_leakage as _c_leakage

5 from imod.prepare.topsystem import c_radial as _c_radial

6

7 WARNING_MESSAGE = (

8 "function has been moved from imod.prepare.surface_water to"

9 "imod.prepare.topsystem, please update your scripts."

10 "imod.prepare.surface_water is going to be removed in version 1.0"

11)

12

13

14 def c_radial(L, kh, kv, B, D):

15 warnings.warn(WARNING_MESSAGE, DeprecationWarning)

16 return _c_radial(L, kh, kv, B, D)

17

18

19 def c_leakage(kh, kv, D, c0, c1, B, length, dx, dy):

20 warnings.warn(WARNING_MESSAGE, DeprecationWarning)

21 return _c_leakage(kh, kv, D, c0, c1, B, length, dx, dy)